/**
  ******************************************************************************
  * @file    DMA_TIM1BurstMode/main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01/22/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "stm8l_eval.h"

 
 // @addtogroup STM8L15x_UsingDMAController_AN
 // @addtogroup DMA_TIM1BurstMode

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
void Delay(__IO uint16_t nCount);
void RAM_InitBuffers(void);
extern uint8_t RAMBuffer1[];
extern uint8_t RAMBuffer2[];

uint8_t PSCRHcurrentValue = 0;
uint8_t PSCRLcurrentValue = 0;
uint8_t ARRHcurrentValue  = 0;
uint8_t ARRLcurrentValue  = 0;
uint8_t RCRcurrentValue   = 0;
uint8_t CCR1HcurrentValue = 0;
uint8_t CCR1LcurrentValue = 0;

// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{


  // Enable DMA1 clock 
  CLK_PeripheralClockConfig(CLK_Peripheral_DMA1, ENABLE);
  
  // Enable Timers clock 
	CLK_PeripheralClockConfig(CLK_Peripheral_TIM1,ENABLE);
  
  // Init RAM Buffers
  RAM_InitBuffers();
	
  // TIM1 Channel1 configuration 
	GPIO_Init(GPIOD,  GPIO_Pin_2, GPIO_Mode_Out_PP_Low_Fast);
	
  STM_EVAL_PBInit(BUTTON_KEY, BUTTON_MODE_EXTI);
  EXTI_SetPinSensitivity(EXTI_Pin_1, EXTI_Trigger_Falling);
  
  
	// Configure TIM1 channel 1 to genere an PWM output 		
  TIM1_OC1Init(TIM1_OCMode_PWM1, TIM1_OutputState_Enable, 
               TIM1_OutputNState_Disable, 0/*TIM1_Pulse*/, 
               TIM1_OCPolarity_Low, TIM1_OCNPolarity_Low, 
               TIM1_OCIdleState_Reset, TIM1_OCNIdleState_Reset);

	
  TIM1_Cmd(ENABLE);
	TIM1_CtrlPWMOutputs(ENABLE);
	

  TIM1_DMAConfig(TIM1_DMABase_PSCH, TIM1_DMABurstLength_7Byte);
  TIM1_DMACmd(TIM1_DMASource_COM, ENABLE);

  enableInterrupts();
  
  while (1)
  {
    PSCRHcurrentValue = TIM1->PSCRH;
    PSCRLcurrentValue = TIM1->PSCRL;
    ARRHcurrentValue  = TIM1->ARRH;
    ARRLcurrentValue  = TIM1->ARRL;
    RCRcurrentValue   = TIM1->RCR;
    CCR1HcurrentValue = TIM1->CCR1H;
    CCR1LcurrentValue = TIM1->CCR1L;
   }
}

/**
  * @brief  Inserts a delay time.
  * @param  nCount: specifies the delay time length.
  * @retval None
  */
void Delay(__IO uint16_t nCount)
{
  for (; nCount != 0; nCount--);
}

void RAM_InitBuffers(void)
{
  // RAMBuffer1 Init
  RAMBuffer1[0]= 0xFF; /* PSCRH new value*/
  RAMBuffer1[1]= 0xEE; /* PSCRL new value*/
  RAMBuffer1[2]= 0xDD; /* ARRH new value*/
  RAMBuffer1[3]= 0xCC; /* ARRL new value*/
  RAMBuffer1[4]= 0xBB; /* RCR new value*/
  RAMBuffer1[5]= 0xAA; /* CCR1H new value*/
  RAMBuffer1[6]= 0x99; /* CCR1L new value*/

  // RAMBuffer2 Init
  RAMBuffer2[0]= 0x77; /* PSCRH new value*/
  RAMBuffer2[1]= 0x66; /* PSCRL new value*/
  RAMBuffer2[2]= 0x55; /* ARRH new value*/
  RAMBuffer2[3]= 0x44; /* ARRL new value*/
  RAMBuffer2[4]= 0x33; /* RCR new value*/
  RAMBuffer2[5]= 0x22; /* CCR1H new value*/
  RAMBuffer2[6]= 0x11; /* CCR1L new value*/
}
#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif

