/**
  ******************************************************************************
  * @file    DMA_WFE/main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    01/22/2010
  * @brief   Main program body
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2010 STMicroelectronics</center></h2>
  */

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"
#include "stm8l_eval.h"

 // @addtogroup STM8L15x_UsingDMAController_AN
 // @addtogroup DMA_WFE

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
#define USART1_DR_ADDRESS      ((uint16_t)(USART1_BASE + 0x01))
#define RAM_BUFFER_ADDRESS    ((uint16_t)(&RAMBuffer))
#define RAM_BUFFER_SIZE       ((uint8_t)(0x04))



uint8_t RAMBuffer[RAM_BUFFER_SIZE] ={0,0,0,0};


// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------


// Private function prototypes -----------------------------------------------
void Delay(__IO uint16_t nCount);
void Action(void);
bool Buffercmp(uint8_t* pBuffer1, uint8_t* pBuffer2, uint16_t BufferLength);

// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
  
  // Enable DMA1 clock 
  CLK_PeripheralClockConfig(CLK_Peripheral_DMA1, ENABLE);
  
  // Enable USART1 clock 
	CLK_PeripheralClockConfig(CLK_Peripheral_USART1,ENABLE);

	
  // Leds Init
	STM_EVAL_LEDInit(LED1);
  STM_EVAL_LEDInit(LED2);
	STM_EVAL_LEDInit(LED3);
  STM_EVAL_LEDInit(LED4);

  // Set the USART RX at high level
  GPIO_ExternalPullUpConfig(GPIOC, GPIO_Pin_2, ENABLE);

  // USART1 Config 
  USART_Init(USART1, (uint32_t)9600/*BAUDRATE */, USART_WordLength_8b,
             USART_StopBits_1, USART_Parity_No, USART_Mode_Rx);

  // DMA channel Rx of USART Configuration 
  DMA_Init(DMA1_Channel2, 
          (uint16_t)RAM_BUFFER_ADDRESS, 
          (uint16_t)USART1_DR_ADDRESS,
           RAM_BUFFER_SIZE, DMA_DIR_PeripheralToMemory, DMA_Mode_Circular,
           DMA_MemoryIncMode_Inc, DMA_Priority_Low, DMA_MemoryDataSize_Byte);

  // Enable the USART Rx DMA request 
  USART_DMACmd(USART1, USART_DMAReq_RX, ENABLE);

  
  DMA_ITConfig(DMA1_Channel2, DMA_ITx_TC, ENABLE);
	WFE_WakeUpSourceEventCmd(WFE_Source_DMA1CH23_EV, ENABLE);
	
  // Global DMA Enable 
  DMA_GlobalCmd(ENABLE);

  // Enable the USART Rx DMA channel 
  DMA_Cmd(DMA1_Channel2, ENABLE); 
	
  enableInterrupts();
	
  while(1)
  {    
    // Enter Wait for event mode 
		wfe();
    
    // Do correspondent Action 
    Action();

    /* Clear the Transfer complete 
       channel 2 flag to allow acces 
       to wfe mode again */
    DMA_ClearFlag(DMA1_FLAG_TC2);
  }

 
  

}

/**
  * @brief  Inserts a delay time.
  * @param  nCount: specifies the delay time length.
  * @retval None
  */
void Delay(__IO uint16_t nCount)
{
  for (; nCount != 0; nCount--);
}

void Action(void)
{
	 // All leds off
   STM_EVAL_LEDOff(LED1);
   STM_EVAL_LEDOff(LED3);
   STM_EVAL_LEDOff(LED2);
   STM_EVAL_LEDOff(LED4);

   if (Buffercmp(RAMBuffer,"led1",RAM_BUFFER_SIZE)!= FALSE)
   {
     // Action 1
     STM_EVAL_LEDOn(LED1);
   }
   else if(Buffercmp(RAMBuffer,"led2",RAM_BUFFER_SIZE)!= FALSE)
   {
     // Action 2
     STM_EVAL_LEDOn(LED2);
   }
   else if(Buffercmp(RAMBuffer,"led3",RAM_BUFFER_SIZE)!= FALSE)
   {
     // Action 3
     STM_EVAL_LEDOn(LED3);
   }
   else if(Buffercmp(RAMBuffer,"led4",RAM_BUFFER_SIZE)!= FALSE)
	 {
     // Action 4
     STM_EVAL_LEDOn(LED4);
	 }
   else
   {
     // Error : all leds on
     STM_EVAL_LEDOn(LED1);
     STM_EVAL_LEDOn(LED3);
     STM_EVAL_LEDOn(LED2);
     STM_EVAL_LEDOn(LED4);
   }
   
}

/**
  * @brief  Compares two buffers.
  * @param  pBuffer1, pBuffer2: buffers to be compared.
  * @param  BufferLength: buffer's length
  * @retval TRUE: pBuffer1 identical to pBuffer2
  *         FALSE: pBuffer1 differs from pBuffer2
  */
bool Buffercmp(uint8_t* pBuffer1, uint8_t* pBuffer2, uint16_t BufferLength)
{
  while (BufferLength--)
  {
    if (*pBuffer1 != *pBuffer2)
    {
      return FALSE;
    }
    pBuffer1++;
    pBuffer2++;
  }
  return TRUE;
}
#ifdef  USE_FULL_ASSERT
/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval : None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif

