/**
  ******************************************************************************
  * @file    i2c_ee.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    09/14/2009
  * @brief   Header for i2c_ee.c module
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 

// Define to prevent recursive inclusion ------------------------------------ 
#ifndef __I2C_EE_H
#define __I2C_EE_H

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

// Exported types ------------------------------------------------------------
// Exported constants --------------------------------------------------------

// Use the defines below the choose the EEPROM type 
#define EE_M24C64_32  /* Support the devices: M24C32 and M24C64 */

// Defines for the GPIO pins used for the I2C communication 
#define EE_I2C                I2C1
#define EE_I2C_GPIO           GPIOC
#define EE_I2C_SCL            GPIO_Pin_1
#define EE_I2C_SDA            GPIO_Pin_0

/* For M24C32 and M24C64 devices, E0,E1 and E2 pins are all used for device 
  address selection (ne need for additional address lines). According to the 
  Harware connection on the board (on STM8L1526-EVAL board E0 = E1 = E2 = 0) */
#define EEPROM_HW_ADDRESS     0xA0   /* E0 = E1 = E2 = 0 */ 


// Exported macro ------------------------------------------------------------
// Exported functions ------------------------------------------------------- 
void I2C_EE_Init(void);
void I2C_EE_ByteWrite(uint8_t* pBuffer, uint16_t WriteAddr);
void I2C_EE_PageWrite(uint8_t* pBuffer, uint16_t WriteAddr, uint8_t NumByteToWrite);
void I2C_EE_BufferWrite(uint8_t* pBuffer, uint16_t WriteAddr, uint16_t NumByteToWrite);
void I2C_EE_BufferRead(uint8_t* pBuffer, uint16_t ReadAddr, uint16_t NumByteToRead);
void I2C_EE_WaitEepromStandbyState(void);

#endif /* __I2C_EE_H */



