/**
  ******************************************************************************
  * @file    spi_flash.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    09/14/2009
  * @brief   Header for spi_flash.c module
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 

// Define to prevent recursive inclusion -------------------------------------
#ifndef __SPI_FLASH_H
#define __SPI_FLASH_H

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

// Exported types ------------------------------------------------------------
// Exported constants --------------------------------------------------------

// Defines for the SPI and GPIO pins used to drive the SPI Flash 
#define FLASH_SPI              SPI1
#define FLASH_SPI_GPIO         GPIOB
#define FLASH_SPI_PIN_SCK      GPIO_Pin_5
#define FLASH_SPI_PIN_MOSI     GPIO_Pin_6
#define FLASH_SPI_PIN_MISO     GPIO_Pin_7


#define FLASH_CS           GPIO_Pin_4
#define FLASH_CS_GPIO      GPIOE

// Exported macro ------------------------------------------------------------
// Select SPI FLASH: Chip Select pin low  
#define SPI_FLASH_CS_LOW()     GPIO_ResetBits(FLASH_CS_GPIO, FLASH_CS)
// Deselect SPI FLASH: Chip Select pin high 
#define SPI_FLASH_CS_HIGH()    GPIO_SetBits(FLASH_CS_GPIO, FLASH_CS)

// Exported functions --------------------------------------------------------
// ----- High layer function -----
void SPI_FLASH_Init(void);
void SPI_FLASH_SectorErase(uint32_t SectorAddr);
void SPI_FLASH_BulkErase(void);
void SPI_FLASH_PageWrite(uint8_t* pBuffer, uint32_t WriteAddr, uint16_t NumByteToWrite);
void SPI_FLASH_BufferWrite(uint8_t* pBuffer, uint32_t WriteAddr, uint16_t NumByteToWrite);
void SPI_FLASH_BufferRead(uint8_t* pBuffer, uint32_t ReadAddr, uint16_t NumByteToRead);
uint32_t SPI_FLASH_ReadID(void);
void SPI_FLASH_StartReadSequence(uint32_t ReadAddr);

// ----- Low layer function -----
uint8_t SPI_FLASH_ReadByte(void);
uint8_t SPI_FLASH_SendByte(uint8_t byte);
uint16_t SPI_FLASH_SendHalfWord(uint16_t HalfWord);
void SPI_FLASH_WriteEnable(void);
void SPI_FLASH_WaitForWriteEnd(void);

#endif /* __SPI_FLASH_H */

