/**
  ******************************************************************************
  * @file    tsensor.h
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    09/14/2009
  * @brief   Header for tsensor.c module
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */ 
  
// Define to prevent recursive inclusion -------------------------------------
#ifndef __TSENSOR_H
#define __TSENSOR_H

// Includes ------------------------------------------------------------------
#include "stm8l15x.h"

// Private define ------------------------------------------------------------
#define  I2C_TIMEOUT   (uint32_t)0x3FFFF

// Defines for the GPIO pins used for the I2C communication 
#define LM75_I2C             I2C1
#define LM75_I2C_GPIO        GPIOC
#define LM75_I2C_SCL         GPIO_Pin_1
#define LM75_I2C_SDA         GPIO_Pin_0

#define LM75_INT             GPIO_Pin_4

#define LM75_REG_TEMP        0x00  /* Temperature Register of LM75 */
#define LM75_REG_CONF        0x01  /* Configuration Register of LM75 */
#define LM75_REG_THYS        0x02  /* Temperature Register of LM75 */
#define LM75_REG_TOS         0x03  /* Over-temp Shutdown threshold Register of LM75 */

// Exported types ------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Exported constants --------------------------------------------------------
// Exported macro ------------------------------------------------------------
// Exported functions ------------------------------------------------------- 
void I2C_LM75_Init(void);
ErrorStatus I2C_LM75_Status(void);
uint16_t I2C_LM75_Temp_Read(void);
uint16_t I2C_LM75_Reg_Read(uint8_t RegName);
void I2C_LM75_Reg_Write(uint8_t RegName, uint16_t RegValue);
uint8_t I2C_LM75_ConfReg_Read(void);
void I2C_LM75_ConfReg_Write(uint8_t RegValue);
void I2C_LM75_ShutDown(FunctionalState NewState);
void Thermometer_Temperature(void);

#endif /* __TSENSOR_H */

